Function raqiya_bible_reference::parse_reference_by_text
source · pub fn parse_reference_by_text<S>(
reference: S,
text: &TextId
) -> Option<Reference>where
S: Into<String>,Expand description
Parses a single reference from a string by a given text for the Bible.
Parsing takes into consideration number of chapters found in a book. If the given chapter exceeds the number of chapters, parsing a reference fails.